@@ -8,34 +8,33 @@
 require 'must'
 
 
+class ImplementationError < StandardError ; end
+
 class Module
 
-  def abstract( nam )
-    mname = nameexp_to_string( nam )
+  def abstract( name )
+    mname = _name2str( name )
 
     module_eval %-
       def #{mname}( *args, &blk )
-        raise NotImplementError,
-          "method '#{mname}' is not implemented"
+        raise ImplementationError, "abstract method '#{mname}' is called"
       end
     -
   end
 
-
   def property( name, tipe, r, w )
-    name = nameexp_to_string( name )
-    tipe = typeexp_to_string( tipe )
+    name = _name2str( name )
+    tipe = _type2str( tipe )
 
     if r then
-      module_eval %-
-        def #{name}() @#{name} end
-      -
+			attr name
     end
     if w then
       module_eval %-
         def #{name}=(arg)
-          @#{name} = (arg.must( #{tipe} ))
-          return self
+					arg.must #{tipe}
+          @#{name} = arg
+          arg
         end
       -
     end
@@ -45,8 +44,7 @@ class Module
 end
 
 
-
-def nameexp_to_string( arg )
+def _name2str( arg )
   case arg
   when String  then return arg
   when Integer then return arg.id2name
@@ -55,13 +53,13 @@ def nameexp_to_string( arg )
   end
 end
 
-def typeexp_to_string( arg )
+def _type2str( arg )
   case arg
   when String  then return arg
   when Integer then return arg.id2name
   when Module  then return arg.to_s
   when Array
-    return arg.collect{|i| typeexp_to_string( i ) }.join(',')
+    return arg.collect{|i| _type2str i }.join(',')
   else
     arg.must String, Integer, Module, Array
   end
