@@ -30,38 +30,36 @@ module Recyclable
 
   BEGIN_GC_SIZE = 5
 
+
   def Recyclable.append_features( mod )
     super
 
-    def mod.new( *args, &block )
-      unless @spare then @spare = [] end
+		mod.module_eval '@spare = []'
 
+    def mod.new( *args, &block )
       gavage_collect
 
       if @spare.size > 0 then
-        psr = @spare.shift  # recycle
-        psr.reset( *args, &block )
+        inst = @spare.shift  # recycle
+        inst.reset( *args, &block )
       else
-        psr = super         # make new
+        inst = super         # make new
       end
 
-      return psr
+      return inst
     end
 
-
     def mod.use_instance( *args, &block )
       inst = new( *args, &block )
-      yield inst
+      block.call inst
       inst.type.finished inst
     end
 
-
     def mod.finished( inst )
       @spare.push inst
       gavage_collect
     end
 
-
     def mod.gavage_collect
       if @spare.size > Recyclable::BEGIN_GC_SIZE then
         @spare = @spare[ 0, @spare.size / 2 ]
