@@ -1,5 +1,5 @@
 require 'recycle'
-require 'scanner'
+require 'racc/scanner'
 
 #
 # mailp.rb
